pub enum Command {
List,
Add {
name: String,
ip: IpAddr,
},
Edit {
old_name: String,
new_ip: Option<IpAddr>,
new_name: Option<String>,
},
Remove {
name: String,
partial: bool,
},
Toggle {
name: String,
partial: bool,
},
Update,
}Variants
List
List all host entries
Add
Add a new host entry
Fields
Edit
Edit a host entry (exact match supported)
Fields
Remove
Remove a host entry by name (exact match by default)
Fields
Toggle
Toggle a host entry on or off by name (exact match by default)
Fields
Update
Check for a newer version and update if one is available